#
# spec file for package zxing-cpp
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 1
Name:           zxing-cpp
Version:        1.2.0
Release:        9.7.1
Summary:        Library for processing 1D and 2D barcodes
License:        Apache-2.0 AND Zlib AND LGPL-2.1-with-Qt-Company-Qt-exception-1.1
Group:          Development/Languages/C and C++
URL:            https://github.com/nu-book/zxing-cpp/
Source0:        %{url}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source99:       baselibs.conf
# PATCH-FIX-OPENSUSE cmake-check-system-first.patch -- Search system for needed libraries first
Patch0:         cmake-check-system-first.patch
# PATCH-FIX-UPSTREAM 269.patch -- Update stb_image/stb_image_write
Patch1:         269.patch
BuildRequires:  pkgconfig
# Use cmake3 package on SLE12 because cmake is too old (version 3.5)
%if !0%{?is_opensuse} && 0%{?sle_version} < 150000
BuildRequires:  cmake3-full >= 3.10
BuildRequires:  gcc11-c++
%else
BuildRequires:  cmake >= 3.10
BuildRequires:  gcc-c++
%endif
# only TW has fmt
%if 0%{?suse_version} > 1500
# For blackbox tests
BuildRequires:  cmake(fmt) >= 7.1.2
%endif

%description
ZXing ("zebra crossing") is an multi-format 1D/2D barcode image
processing library. This package provides a C++ implementation.

%package -n libZXing%{sover}
Summary:        Library for processing 1D and 2D barcodes
# called libZXing in the 1.1.0 update
Group:          System/Libraries
Provides:       libZXingCore%{sover} = %{version}
Obsoletes:      libZXingCore%{sover} < %{version}

%description -n libZXing%{sover}
ZXing ("zebra crossing") is an multi-format 1D/2D barcode image
processing library. This package provides a C++ implementation.

%package devel
Summary:        Header files for zxing, a library for processing 1D and 2D barcodes
Group:          Development/Languages/C and C++
Requires:       libZXing%{sover} = %{version}

%description devel
ZXing ("zebra crossing") is an multi-format 1D/2D barcode image
processing library. This package provides header files to use ZXing in
other applications.

%prep
%autosetup -p1

%build
# Use g++-11 to build a C++17 codebase
# Examples require QT5-base/multimedia, but doing so creates a cycle
# Blackbox tests require fmt
%cmake \
    -DBUILD_EXAMPLES=OFF \
%if !0%{?is_opensuse} && 0%{?sle_version} < 150000
    -DCMAKE_CXX_COMPILER=/usr/bin/g++-11 \
%endif
%if 0%{?suse_version} < 1550
    -DBUILD_BLACKBOX_TESTS=OFF \
%endif
 ;
%cmake_build

%install
%cmake_install

%check
%if 0%{?sle_version}
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
%endif
%ctest

%post -n libZXing%{sover} -p /sbin/ldconfig
%postun -n libZXing%{sover} -p /sbin/ldconfig

%files -n libZXing%{sover}
%doc README.md
%license LICENSE.*
%{_libdir}/libZXing.so.%{sover}
%{_libdir}/libZXing.so.%{sover}.*

%files devel
%license LICENSE.*
%{_includedir}/ZXing/
%{_libdir}/cmake/ZXing/
%{_libdir}/libZXing.so
%{_libdir}/pkgconfig/zxing.pc

%changelog
* Wed Jan 19 2022 danilo.spinella@suse.com
- Update stb_image/stb_image_write to include the fixes for
  the following CVEs:
  CVE-2021-28021, bsc#1191743
  CVE-2021-42715, bsc#1191942
  CVE-2021-42716, bsc#1191944
  * 269.patch
* Fri Nov  5 2021 danilo.spinella@suse.com
- Do not build examples to avoid a cycle with QT5Multimedia
* Wed Nov  3 2021 danilo.spinella@suse.com
- Use the updated cmake3-full package instead of cmake on SLE12
- Do not build examples on SLE12
- Only build blackbox tests on TW
* Sat May 29 2021 rpm@fthiessen.de
- Update to 1.2.0
  * new BarcodeFormat names, old ones are deprecated
  * new ZXingQtCamReader demo app based on QtMultimedia and QtQuick
  * new QRCode reader, faster and better support for rotated symbols
  * added Structured Append support for DataMatrix, Aztec and MaxiCode
  * added DMRE support for DataMatrix
  * switch to the reimplemented 1D detectors, about 5x faster
  * a lot faster and more capable isPure detection for all 2D codes
  * 20%% faster ReedSolomon error correcting
  * PDF417 is faster and supports flipped symbols
  * reduced false positive rate for UPC/EAN barcodes and improved
    Add-On symbol handling
  * proper ECI handling in all 2D barcodes
  * much improved python wrapper
  * deprecate the use of ResultMetadata
- Add cmake-check-system-first.patch
- Drop upstream merged 0001-Fix-build-with-GCC-11.patch
* Tue Feb  9 2021 christophe@krop.fr
- Update to 1.1.1. No changelog available.
- Drop fix-pkg-config-file.patch. Merged upstream
- Add 0001-Fix-build-with-GCC-11.patch to fix GCC 11 build
  issues (boo#1181915)
* Fri Jan 15 2021 sflees@suse.de
- Use %%cmake_build instead of %%make_jobs
- Shouldn't need -DBUILD_SHARED_LIBRARY=ON
* Fri Oct 23 2020 alarrosa@suse.com
- Add baselibs.conf
* Fri Sep  4 2020 alarrosa@suse.com
- Add fix for pkg-config file so the version and library are set properly
  in the resulting .pc file:
  * fix-pkg-config-file.patch
* Sun Aug 16 2020 christophe@krop.fr
- Update to 1.1.0
  * Add Python binding
  * Bug fixes from upstream XZing project
  * Many performance improvements for 1D readers
  * More meta-data exported when reading specific format
  * Minor bug fixes and improvements for corner cases
  * Improve DataMatrix encoder
  * Add interface to simplify basic usage
  * WASM API to support pixels array as input
  * Few minor bug fixes
  * A new and (hopefully) 'future proof' single ReadBarcode entry point
    into the decoding functionality.
  * The LuminanceSource based API is now deprecated but still compiles.
  * A new BarcodeFormats flag type to specify the set of barcodes to look for.
  * Deprecated unrelyable Result::resultPoints in favor of well defined
    Result::position.
  * Deprecated Result::metadata() -> ORIENTATION in favor
    of Result::orientation.
  * New Binarizer enum in DecodeHints to specify the binarizer for
    the ReadBarcode API.
  * New DecodeHints::isPure property to speed up detection for
    'pure' input use-cases.
  * New 'unified' CMake structure to build (most) of the project from
    the top-level project.
  * New ZXingReader and ZXingWriter example code also meant for distributing.
  * New simplified and consistent Python API (breaking change)
  * ReedSolomon error detection code 2x speedup.
  * Enable basic MaxiCode support.
  * Fix coutry-code metatdata decoding for UPC/EAN codes.
  * Slightly improved QRCode detection for rotated symbols.
  * Faster PDF417 decoder.
  * Lots of minor code readability and general cleanup improvements.
- Drop patches:
  * add-missing-includes-of-stdexcept-header.patch
  * fix-library-installation-and-versioning.patch
* Thu Dec  5 2019 mliska@suse.cz
- Add add-missing-includes-of-stdexcept-header.patch
  in order to fix boo#1158377.
* Thu May 23 2019 jengelh@inai.de
- Trim metadata redundancies from description.
* Wed May 22 2019 lbeltrame@kde.org
- Fixup URL and Source
* Fri May 17 2019 lbeltrame@kde.org
- Initial package for openSUSE
- Add upstream patch to add proper installability and library
  versioning:
  * fix-library-installation-and-versioning.patch
